@@ -69,7 +69,7 @@ from ._resource import BaseResource
 from ._port import PortManager
 from ._logging import logged_api_call
 from ._utils import repr_dict, repr_manager, repr_timestamp, matches_filters, \
-    divide_filter_args
+    divide_filter_args, RC_ADAPTER
 
 __all__ = ['AdapterManager', 'Adapter']
 
@@ -118,7 +118,7 @@ class AdapterManager(BaseManager):
 
         super(AdapterManager, self).__init__(
             resource_class=Adapter,
-            class_name='adapter',
+            class_name=RC_ADAPTER,
             session=cpc.manager.session,
             parent=cpc,
             base_uri='/api/adapters',
@@ -581,3 +581,32 @@ class Adapter(BaseResource):
         body = {'type': adapter_type}
         self.manager.session.post(
             self.uri + '/operations/change-adapter-type', body)
+
+    def dump(self):
+        """
+        Dump this Adapter resource with its properties and child resources
+        (recursively) as a resource definition.
+
+        The returned resource definition has the following format::
+
+            {
+                # Resource properties:
+                "properties": {...},
+
+                # Child resources:
+                "ports": [...],
+            }
+
+        Returns:
+          dict: Resource definition of this resource.
+        """
+
+        # Dump the resource properties
+        resource_dict = super(Adapter, self).dump()
+
+        # Dump the child resources
+        ports = self.ports.dump()
+        if ports:
+            resource_dict['ports'] = ports
+
+        return resource_dict
