@@ -50,18 +50,29 @@ from __future__ import absolute_import
 
 import warnings
 import copy
+try:
+    from collections import OrderedDict
+except ImportError:
+    from ordereddict import OrderedDict
 
 from ._manager import BaseManager
 from ._resource import BaseResource
 from ._lpar import LparManager
-from ._partition import PartitionManager
+from ._partition import PartitionManager, Partition
 from ._activation_profile import ActivationProfileManager
 from ._adapter import AdapterManager
 from ._virtual_switch import VirtualSwitchManager
 from ._capacity_group import CapacityGroupManager
 from ._logging import logged_api_call
-from ._exceptions import ParseError
-from ._utils import matches_filters, divide_filter_args
+from ._exceptions import ParseError, ConsistencyError
+from ._utils import matches_filters, divide_filter_args, \
+    RC_CPC, RC_ADAPTER, RC_CAPACITY_GROUP, RC_HBA, RC_NIC, RC_PARTITION, \
+    RC_NETWORK_PORT, RC_STORAGE_PORT, RC_STORAGE_TEMPLATE, RC_STORAGE_GROUP, \
+    RC_STORAGE_TEMPLATE_VOLUME, RC_STORAGE_VOLUME, RC_VIRTUAL_FUNCTION, \
+    RC_VIRTUAL_STORAGE_RESOURCE, RC_VIRTUAL_SWITCH, RC_STORAGE_SITE, \
+    RC_STORAGE_FABRIC, RC_STORAGE_SWITCH, RC_STORAGE_SUBSYSTEM, \
+    RC_STORAGE_PATH, RC_STORAGE_CONTROL_UNIT, RC_VIRTUAL_TAPE_RESOURCE, \
+    RC_TAPE_LINK, RC_TAPE_LIBRARY
 
 __all__ = ['CpcManager', 'Cpc']
 
@@ -95,7 +106,7 @@ class CpcManager(BaseManager):
 
         super(CpcManager, self).__init__(
             resource_class=Cpc,
-            class_name='cpc',
+            class_name=RC_CPC,
             session=client.session,
             parent=None,
             base_uri='/api/cpcs',
@@ -450,6 +461,67 @@ class Cpc(BaseResource):
             new_exc.__cause__ = None
             raise new_exc  # ValueError
 
+    def dump(self):
+        """
+        Dump this Cpc resource with its properties and child resources
+        (recursively) as a resource definition.
+
+        The returned resource definition has the following format::
+
+            {
+                # Resource properties:
+                "properties": {...},
+
+                # Child resources for any CPC mode:
+                "capacity_groups": [...],
+
+                # Child resources for DPM mode:
+                "partitions": [...],
+                "adapters": [...],
+                "virtual_switches": [...],
+
+                # Child resources for classic mode:
+                "lpars": [...],  # Faked Lpar children
+                "reset_activation_profiles": [...],
+                "image_activation_profiles": [...],
+                "load_activation_profiles": [...],
+            }
+
+        Returns:
+          dict: Resource definition of this resource.
+        """
+
+        # Dump the resource properties
+        resource_dict = super(Cpc, self).dump()
+
+        # Dump the child resources
+        capacity_groups = self.capacity_groups.dump()
+        if capacity_groups:
+            resource_dict['capacity_groups'] = capacity_groups
+        partitions = self.partitions.dump()
+        if partitions:
+            resource_dict['partitions'] = partitions
+        adapters = self.adapters.dump()
+        if adapters:
+            resource_dict['adapters'] = adapters
+        virtual_switches = self.virtual_switches.dump()
+        if virtual_switches:
+            resource_dict['virtual_switches'] = virtual_switches
+        lpars = self.lpars.dump()
+        if lpars:
+            resource_dict['lpars'] = lpars
+        reset_act_profiles = self.reset_activation_profiles.dump()
+        if reset_act_profiles:
+            resource_dict['reset_activation_profiles'] = reset_act_profiles
+        image_act_profiles = self.image_activation_profiles.dump()
+        if image_act_profiles:
+            resource_dict['image_activation_profiles'] = image_act_profiles
+        load_act_profiles = self.load_activation_profiles.dump()
+        if load_act_profiles:
+            resource_dict['load_activation_profiles'] = load_act_profiles
+
+        return resource_dict
+
     @logged_api_call
     def feature_enabled(self, feature_name):
         """
@@ -572,6 +644,16 @@ class Cpc(BaseResource):
         """
         Start this CPC, using the HMC operation "Start CPC".
 
+        This operation performs an orderly start of the CPC, including:
+
+        * Turning CPC power on.
+        * Performing a power-on reset, this includes allocating system
+          resources to the CPC.
+        * Starting partitions that are in the auto-start list of the CPC.
+
+        The CPC must be set for DPM operational mode (i.e. its 'dpm-enabled'
+        property is True) and must currently be inactive.
+
         Authorization requirements:
 
         * Object-access permission to this CPC.
@@ -625,7 +707,17 @@ class Cpc(BaseResource):
     @logged_api_call
     def stop(self, wait_for_completion=True, operation_timeout=None):
         """
-        Stop this CPC, using the HMC operation "Stop CPC".
+        Stop this DPM-mode CPC, using the HMC operation "Stop CPC".
+
+        This operation performs an orderly shutdown of the CPC, including:
+
+        * Stopping all partitions.
+        * Ending hardware activity.
+        * Clearing, releasing, and de-allocating hardware resources.
+        * Turning off CPC power.
+
+        The CPC must be set for DPM operational mode (i.e. its 'dpm-enabled'
+        property is True) and must currently be active.
 
         Authorization requirements:
 
@@ -677,6 +769,161 @@ class Cpc(BaseResource):
             operation_timeout=operation_timeout)
         return result
 
+    @logged_api_call
+    def activate(self, activation_profile_name, force=False,
+                 wait_for_completion=True, operation_timeout=None):
+        """
+        Activate this classic-mode CPC, using the HMC operation "Activate CPC".
+
+        This operation performs an orderly start of the CPC, including:
+
+        * Turning CPC power on.
+        * Performing a power-on reset, this includes allocating system
+          resources to the CPC as defined by the reset activation profile.
+        * Activating LPARs that are in the auto-start list defined by the
+          reset activation profile.
+
+        If the CPC is already active in classic mode, only the operations are
+        performed that are needed to get into the state defined by the
+        specified reset activation profile.
+
+        The CPC must be set for classic operational mode (i.e. its 'dpm-enabled'
+        property is False).
+
+        Authorization requirements:
+
+        * Object-access permission to this CPC.
+        * Task permission for the "Activate" task.
+
+        Parameters:
+
+          activation_profile_name (:term:`string`):
+            Name of the reset activation profile used to activate the CPC.
+
+          force (bool):
+            Boolean controlling whether the operation is permitted if the CPC
+            is in 'operating' status.
+
+          wait_for_completion (bool):
+            Boolean controlling whether this method should wait for completion
+            of the requested asynchronous HMC operation, as follows:
+
+            * If `True`, this method will wait for completion of the
+              asynchronous job performing the operation.
+
+            * If `False`, this method will return immediately once the HMC has
+              accepted the request to perform the operation.
+
+          operation_timeout (:term:`number`):
+            Timeout in seconds, for waiting for completion of the asynchronous
+            job performing the operation. The special value 0 means that no
+            timeout is set. `None` means that the default async operation
+            timeout of the session is used. If the timeout expires when
+            `wait_for_completion=True`, a
+            :exc:`~zhmcclient.OperationTimeout` is raised.
+
+        Returns:
+
+          `None` or :class:`~zhmcclient.Job`:
+
+            If `wait_for_completion` is `True`, returns `None`.
+
+            If `wait_for_completion` is `False`, returns a
+            :class:`~zhmcclient.Job` object representing the asynchronously
+            executing job on the HMC.
+
+        Raises:
+
+          :exc:`~zhmcclient.HTTPError`
+          :exc:`~zhmcclient.ParseError`
+          :exc:`~zhmcclient.AuthError`
+          :exc:`~zhmcclient.ConnectionError`
+          :exc:`~zhmcclient.OperationTimeout`: The timeout expired while
+            waiting for completion of the operation.
+        """
+        body = {
+            'activation-profile-name': activation_profile_name,
+            'force': force,
+        }
+        result = self.manager.session.post(
+            self.uri + '/operations/activate',
+            body,
+            wait_for_completion=wait_for_completion,
+            operation_timeout=operation_timeout)
+        return result
+
+    @logged_api_call
+    def deactivate(self, force=False, wait_for_completion=True,
+                   operation_timeout=None):
+        """
+        Deactivate this CPC, using the HMC operation "Deactivate CPC".
+
+        This operation performs an orderly shutdown of the CPC, including:
+
+        * Stopping all LPARs.
+        * Ending hardware activity.
+        * Clearing, releasing, and de-allocating hardware resources.
+        * Turning off CPC power.
+
+        The CPC must be set for classic operational mode (i.e. its 'dpm-enabled'
+        property is False).
+
+        Authorization requirements:
+
+        * Object-access permission to this CPC.
+        * Task permission for the "Deactivate" task.
+
+        Parameters:
+
+          force (bool):
+            Boolean controlling whether the operation is permitted if the CPC
+            is in 'operating' status.
+
+          wait_for_completion (bool):
+            Boolean controlling whether this method should wait for completion
+            of the requested asynchronous HMC operation, as follows:
+
+            * If `True`, this method will wait for completion of the
+              asynchronous job performing the operation.
+
+            * If `False`, this method will return immediately once the HMC has
+              accepted the request to perform the operation.
+
+          operation_timeout (:term:`number`):
+            Timeout in seconds, for waiting for completion of the asynchronous
+            job performing the operation. The special value 0 means that no
+            timeout is set. `None` means that the default async operation
+            timeout of the session is used. If the timeout expires when
+            `wait_for_completion=True`, a
+            :exc:`~zhmcclient.OperationTimeout` is raised.
+
+        Returns:
+
+          `None` or :class:`~zhmcclient.Job`:
+
+            If `wait_for_completion` is `True`, returns `None`.
+
+            If `wait_for_completion` is `False`, returns a
+            :class:`~zhmcclient.Job` object representing the asynchronously
+            executing job on the HMC.
+
+        Raises:
+
+          :exc:`~zhmcclient.HTTPError`
+          :exc:`~zhmcclient.ParseError`
+          :exc:`~zhmcclient.AuthError`
+          :exc:`~zhmcclient.ConnectionError`
+          :exc:`~zhmcclient.OperationTimeout`: The timeout expired while
+            waiting for completion of the operation.
+        """
+        body = {'force': force}
+        result = self.manager.session.post(
+            self.uri + '/operations/deactivate',
+            body,
+            wait_for_completion=wait_for_completion,
+            operation_timeout=operation_timeout)
+        return result
+
     @logged_api_call
     def import_profiles(self, profile_area, wait_for_completion=True,
                         operation_timeout=None):
@@ -1559,3 +1806,435 @@ class Cpc(BaseResource):
         self.manager.session.post(
             self.uri + '/operations/remove-temp-capacity',
             body=body)
+
+    @logged_api_call
+    def set_auto_start_list(self, auto_start_list):
+        """
+        Set the auto-start list of partitions for this CPC.
+
+        The current auto-start list is replaced with this new list.
+
+        The auto-start list may contain named partition groups that are formed
+        just for the purpose of auto-starting (they have nothing to do with
+        Group objects on the HMC).
+
+        This method performs the "Set Auto-Start List" HMC operation.
+
+        This method requires the CPC to be in DPM mode.
+
+        Parameters:
+
+          auto_start_list (list): The auto-start list to be set.
+
+            Each list item is one of:
+
+            - tuple(partition, post_start_delay)
+            - tuple(partition_list, name, description, post_start_delay)
+
+            Where:
+
+            - partition (:class:`~zhmcclient.Partition`): The partition to be
+              auto-started.
+            - post_start_delay (int): Delay in seconds to wait after starting
+              this partition or partition group, and before the next partition
+              or partition group in the list is started.
+            - partition_list (list of :class:`~zhmcclient.Partition`): The
+              partitions in the partition group to be auto-started.
+            - name (string): Name of the partition group.
+            - description (string): Description of the partition group.
+
+        Authorization requirements:
+
+        * Object-access permission to this CPC.
+        * Task permission to the "System Details" task.
+        * Object-access permission to all partitions specified in the auto-start
+          list.
+
+        Raises:
+
+          :exc:`~zhmcclient.HTTPError`
+          :exc:`~zhmcclient.ParseError`
+          :exc:`~zhmcclient.AuthError`
+          :exc:`~zhmcclient.ConnectionError`
+        """
+        auto_start_body = []
+        for item in auto_start_list:
+            if isinstance(item[0], Partition):
+                partition, post_start_delay = item
+                auto_start_item = {
+                    'type': 'partition',
+                    'post-start-delay': post_start_delay,
+                    'partition-uri': partition.uri,
+                }
+                auto_start_body.append(auto_start_item)
+            elif isinstance(item[0], (list, tuple)):
+                partition_list, name, description, post_start_delay = item
+                auto_start_item = {
+                    'type': 'partition-group',
+                    'post-start-delay': post_start_delay,
+                    'name': name,
+                    'description': description,
+                    'partition-uris': [p.uri for p in partition_list],
+                }
+                auto_start_body.append(auto_start_item)
+            else:
+                raise TypeError(
+                    "Invalid type for auto_start_list parameter: {}".
+                    format(type(auto_start_list)))
+
+        body = {
+            'auto-start-list': auto_start_body,
+        }
+        self.manager.session.post(
+            self.uri + '/operations/set-auto-start-list',
+            body=body)
+
+    @logged_api_call
+    def import_dpm_configuration(self, dpm_configuration):
+        """
+        Import a DPM configuration into this CPC.
+
+        This includes settable CPC properties, settable properties of physical
+        adapters, Hipersocket adapters, partitions with their child objects,
+        virtual functions, virtual switches, capacity groups, storage related
+        resources, storage ports, and network ports.
+
+        This method performs the "Import DPM Configuration" HMC operation.
+
+        This method requires the CPC to be in DPM mode.
+
+        Authorization requirements:
+
+        * Object-access permission to this CPC.
+        * Task permission to the "Import Dynamic Partition Manager
+          Configuration" task.
+
+        Parameters:
+
+          dpm_configuration (dict): A DPM configuration, represented as a
+            dictionary with the fields described for the
+            "Import DPM Configuration" operation in the :term:`HMC API` book.
+
+            Resource URIs are represented as URI strings in the fields of
+            the DPM configuration, as described for the request body fields
+            of the HMC operation. URIs of imported resource objects can be
+            chosen to be preserved or newly allocated via the "preserve-uris"
+            field.
+
+            Adapter PCHIDs may be different between the imported adapter
+            objects and the actual adapters in this CPC and can be mapped
+            via the "adapter-mapping" field.
+
+            Host WWPNs of FICON adapters can be chosen to be preserved
+            or newly allocated via the "preserve-wwpns" field.
+
+        Returns:
+          list or None:
+            If the complete input DPM configuration has been applied
+            to the CPC, `None` is returned.
+
+            If only a part of the input DPM configuration has been applied,
+            a list of dict objects is returned that describe what was not
+            applied.
+            For details, see the description of the response of the
+            "Import DPM Configuration" operation in the :term:`HMC API` book.
+
+            To verify that the complete input DPM configuration has been
+            applied, the caller must verify the return value to be `None` and
+            not just verify that no exceptions have been raised.
+
+        Raises:
+
+          :exc:`~zhmcclient.HTTPError`
+          :exc:`~zhmcclient.ParseError`
+          :exc:`~zhmcclient.AuthError`
+          :exc:`~zhmcclient.ConnectionError`
+        """
+        body = dpm_configuration
+        result = self.manager.session.post(
+            self.uri + '/operations/import-dpm-config',
+            body=body)
+        return result
+
+    @logged_api_call
+    def export_dpm_configuration(self):
+        """
+        Export a DPM configuration from this CPC and return it.
+
+        The DPM configuration includes settable CPC properties and all DPM
+        specific objects of or associated with the CPC, such as adapters with
+        their ports, virtual switches, partitions with their child objects,
+        capacity groups, and various storage and tape related resources.
+
+        Note that all adapters of the CPC are exported, even when they are not
+        used by partitions.
+
+        This method performs the "Get Inventory" HMC operation and extracts
+        all information into the result.
+
+        This method requires the CPC to be in DPM mode.
+
+        Authorization requirements:
+
+        * Object-access permission to this CPC.
+
+        Returns:
+          dict:
+            A DPM configuration, represented as a dictionary with the
+            fields described for the "Import DPM Configuration" operation
+            in the :term:`HMC API` book.
+
+            Resource URIs are represented as URI strings in the fields of
+            the DPM configuration, as described for the request body fields
+            of the HMC operation.
+
+            The optional "preserve-uris", "preserve-wwpns", and
+            "adapter-mapping" fields will not be in the returned dictionary,
+            so their defaults will be used when importing this DPM configuration
+            unchanged to a CPC.
+
+            The returned DPM configuration object can be passed to
+            :meth:`~zhmcclient.Cpc.import_dpm_configuration` either unchanged,
+            or after changing it, e.g. by adding the optional "preserve-uris",
+            "preserve-wwpns", or "adapter-mapping" fields.
+
+        Raises:
+          :exc:`~zhmcclient.HTTPError`
+          :exc:`~zhmcclient.ParseError`
+          :exc:`~zhmcclient.AuthError`
+          :exc:`~zhmcclient.ConnectionError`
+          :exc:`~zhmcclient.ConsistencyError` - issues with inventory data
+        """
+        inventory_list = retrieveInventoryData(self.manager.client)
+        cpc_uri = self.get_property('object-uri')
+        config_dict = convertToConfig(inventory_list, cpc_uri)
+        return config_dict
+
+
+# Functions used by Cpc.export_dpm_configuration().
+# Some of these functions were adapted from code in the
+# exportDpmResourcesToFile.py script available at
+# https://www-01.ibm.com/servers/resourcelink/lib03020.nsf/0/2C88A77CEA71062E8525829500667BCD?OpenDocument
+
+def extractByParent(classname, parent_list, inventory_list):
+    """
+    Extract all items from inventory_list that have the classname and where the
+    parent is in parent_list.
+
+    This is used for example to get all partitions of a CPC or all NICs of a
+    partition.
+    """
+    result_list = [x for x in inventory_list
+                   if (x['class'] == classname and x['parent'] in parent_list)]
+    return result_list
+
+
+def extractByPropertyInListValue(classname, prop_name, values, inventory_list):
+    """
+    Extract all items from inventory_list that have the classname and where the
+    value of the prop_name property is in the values list.
+
+    Used for example to get all storage groups that have value for property
+    'cpc-uri' in a list of CPC uris.
+    """
+    result_list = [x for x in inventory_list
+                   if x['class'] == classname and x[prop_name] in values]
+    return result_list
+
+
+def extractByValueInListProperty(classname, value, prop_name, inventory_list):
+    """
+    Extract all items from inventory_list that have the classname and where
+    value is in the value of the prop_name array property.
+
+    Used for example to get all storage-sites that have a 'cpc-uris' list
+    containing the specified cpc-uri value.
+    """
+    result_list = [x for x in inventory_list
+                   if x['class'] == classname and value in x[prop_name]]
+    return result_list
+
+
+def extractCpc(cpc_uri, inventory_list):
+    """
+    Extract the CPC item from inventory_list that has the specified cpc_uri.
+    """
+    cpcs = [x for x in inventory_list
+            if x['class'] == RC_CPC and x['object-uri'] == cpc_uri]
+    cpc_len = len(cpcs)
+    if cpc_len == 0:
+        raise ConsistencyError(
+            "Inventory data does not contain CPC with URI {}".
+            format(cpc_uri))
+    if cpc_len > 1:
+        raise ConsistencyError(
+            "Inventory data contains multiple ({}) CPCs with URI {}".
+            format(cpc_len, cpc_uri))
+    cpc = cpcs[0]
+    return cpc
+
+
+def extractAdapters(cpc_uri, inventory_list):
+    """
+    Extract all items from inventory_list with class "adapter" and parent
+    cpc_uri.
+    """
+
+    # Export all adapters even when not used. If False, only adapters that
+    # are used, are exported.
+    all_adapters = True
+
+    result_list = []
+    excluded_classes = (RC_ADAPTER, RC_NETWORK_PORT, RC_STORAGE_PORT)
+    for x in inventory_list:
+        if x['class'] == RC_ADAPTER and x['parent'] == cpc_uri:
+            # It is an adapter of this CPC
+            if all_adapters:
+                result_list.append(x)
+            elif containsItemsWithSubstring(
+                    x['object-uri'], excluded_classes, inventory_list):
+                # The adapter is used.
+                # Note that the test above checks only adapter URIs, but in
+                # case of OSA adapters the virtual switches are referencing
+                # the backing network ports, and in case of FICON adapters the
+                # HBAs/VSRs are referencing the storage ports. The reason this
+                # test works nevertheless, is that the storage and network ports
+                # are element resources that are children of the adapter
+                # resources, and thus their URIs happen to contain the adapter
+                # URIs.
+                result_list.append(x)
+    return result_list
+
+
+def containsItemsWithSubstring(substr, excluded_classes, inventory_list):
+    """
+    Check if inventory_list contains items where substr appears in the
+    string representation of the item, excluding the items with a class in
+    excluded_classes.
+    """
+    find_list = [x for x in inventory_list
+                 if x['class'] not in excluded_classes
+                 and str(x).find(substr) != -1]  # noqa: W503
+    found = len(find_list) > 0
+    return found
+
+
+def retrieveInventoryData(client):
+    """
+    Retrieve inventory data from the HMC.
+    Returns the inventory list from Client.get_inventory().
+    """
+    resource_classes = ['dpm-resources', 'cpc']
+    inventory_list = client.get_inventory(resource_classes)
+    for res in inventory_list:
+        uri = res.get('object-uri') or res.get('element-uri')
+        if not uri:
+            raise ConsistencyError(
+                "Inventory data has an item without URI property: {}".
+                format(res))
+    return inventory_list
+
+
+def convertToConfig(inventory_list, cpc_uri):
+    """
+    Convert the inventory list to a DPM configuration dict.
+    """
+    config_dict = OrderedDict()
+
+    cpc = extractCpc(cpc_uri, inventory_list)
+    cpc_uris = [cpc_uri]
+
+    config_dict['se-version'] = cpc.get('se-version', None)
+    config_dict['available-features-list'] = \
+        cpc.get('available-features-list', [])
+    config_dict['cpc-properties'] = {
+        'auto-start-list': cpc.get('auto-start-list', None),
+        'description': cpc.get('description', None),
+        'management-world-wide-port-name':
+            cpc.get('management-world-wide-port-name', None),
+    }
+
+    config_dict['adapters'] = extractAdapters(
+        cpc_uri, inventory_list)
+    adapter_uris = [x['object-uri'] for x in config_dict['adapters']]
+
+    config_dict['partitions'] = extractByParent(
+        RC_PARTITION, cpc_uris, inventory_list)
+    partition_uris = [x['object-uri'] for x in config_dict['partitions']]
+
+    config_dict['nics'] = extractByParent(
+        RC_NIC, partition_uris, inventory_list)
+    config_dict['hbas'] = extractByParent(
+        RC_HBA, partition_uris, inventory_list)
+    config_dict['virtual-functions'] = extractByParent(
+        RC_VIRTUAL_FUNCTION, partition_uris, inventory_list)
+
+    config_dict['virtual-switches'] = extractByParent(
+        RC_VIRTUAL_SWITCH, cpc_uris, inventory_list)
+
+    config_dict['capacity-groups'] = extractByParent(
+        RC_CAPACITY_GROUP, cpc_uris, inventory_list)
+
+    config_dict['storage-sites'] = extractByValueInListProperty(
+        RC_STORAGE_SITE, cpc_uri, 'cpc-uris', inventory_list)
+    storage_site_uris = [x['object-uri'] for x in config_dict['storage-sites']]
+
+    config_dict['storage-subsystems'] = extractByPropertyInListValue(
+        RC_STORAGE_SUBSYSTEM, 'storage-site-uri', storage_site_uris,
+        inventory_list)
+    storage_subsystem_uris = \
+        [x['object-uri'] for x in config_dict['storage-subsystems']]
+
+    config_dict['storage-fabrics'] = extractByPropertyInListValue(
+        RC_STORAGE_FABRIC, 'cpc-uri', cpc_uris, inventory_list)
+    config_dict['storage-switches'] = extractByPropertyInListValue(
+        RC_STORAGE_SWITCH, 'storage-site-uri', storage_site_uris,
+        inventory_list)
+
+    config_dict['storage-control-units'] = extractByPropertyInListValue(
+        RC_STORAGE_CONTROL_UNIT, 'parent', storage_subsystem_uris,
+        inventory_list)
+    storage_control_unit_uris = \
+        [x['object-uri'] for x in config_dict['storage-control-units']]
+
+    config_dict['storage-paths'] = extractByPropertyInListValue(
+        RC_STORAGE_PATH, 'parent', storage_control_unit_uris, inventory_list)
+
+    config_dict['storage-ports'] = extractByPropertyInListValue(
+        RC_STORAGE_PORT, 'parent', adapter_uris, inventory_list)
+
+    config_dict['network-ports'] = extractByPropertyInListValue(
+        RC_NETWORK_PORT, 'parent', adapter_uris, inventory_list)
+
+    config_dict['storage-groups'] = extractByPropertyInListValue(
+        RC_STORAGE_GROUP, 'cpc-uri', cpc_uris, inventory_list)
+    storage_group_uris = \
+        [x['object-uri'] for x in config_dict['storage-groups']]
+
+    config_dict['storage-volumes'] = extractByPropertyInListValue(
+        RC_STORAGE_VOLUME, 'parent', storage_group_uris, inventory_list)
+
+    config_dict['storage-templates'] = extractByPropertyInListValue(
+        RC_STORAGE_TEMPLATE, 'cpc-uri', cpc_uris, inventory_list)
+    storage_template_uris = \
+        [x['object-uri'] for x in config_dict['storage-templates']]
+
+    config_dict['storage-template-volumes'] = extractByPropertyInListValue(
+        RC_STORAGE_TEMPLATE_VOLUME, 'parent', storage_template_uris,
+        inventory_list)
+
+    config_dict['virtual-storage-resources'] = extractByPropertyInListValue(
+        RC_VIRTUAL_STORAGE_RESOURCE, 'parent', storage_group_uris,
+        inventory_list)
+
+    config_dict['tape-links'] = extractByPropertyInListValue(
+        RC_TAPE_LINK, 'cpc-uri', cpc_uris, inventory_list)
+    tape_link_uris = [x['object-uri'] for x in config_dict['tape-links']]
+
+    config_dict['tape-libraries'] = extractByPropertyInListValue(
+        RC_TAPE_LIBRARY, 'cpc-uri', cpc_uris, inventory_list)
+
+    config_dict['virtual-tape-resources'] = extractByParent(
+        RC_VIRTUAL_TAPE_RESOURCE, tape_link_uris, inventory_list)
+
+    return config_dict
