@@ -34,7 +34,7 @@ import copy
 from ._manager import BaseManager
 from ._resource import BaseResource
 from ._logging import logged_api_call
-from ._utils import matches_filters
+from ._utils import matches_filters, RC_HBA
 
 __all__ = ['HbaManager', 'Hba']
 
@@ -65,7 +65,7 @@ class HbaManager(BaseManager):
 
         super(HbaManager, self).__init__(
             resource_class=Hba,
-            class_name='hba',
+            class_name=RC_HBA,
             session=partition.manager.session,
             parent=partition,
             base_uri='{}/hbas'.format(partition.uri),
@@ -263,6 +263,14 @@ class Hba(BaseResource):
         self.manager._name_uri_cache.delete(
             self.get_properties_local(self.manager._name_prop, None))
 
+        parent_hba_uris = self.manager.parent.get_properties_local(
+            'hba-uris')
+        if parent_hba_uris:
+            try:
+                parent_hba_uris.remove(self._uri)
+            except ValueError:
+                pass
+
     @logged_api_call
     def update_properties(self, properties):
         """
