@@ -34,7 +34,7 @@ from ._manager import BaseManager
 from ._resource import BaseResource
 from ._exceptions import StatusTimeout
 from ._logging import logged_api_call
-from ._utils import matches_filters, divide_filter_args
+from ._utils import matches_filters, divide_filter_args, RC_LOGICAL_PARTITION
 
 __all__ = ['LparManager', 'Lpar']
 
@@ -70,7 +70,7 @@ class LparManager(BaseManager):
 
         super(LparManager, self).__init__(
             resource_class=Lpar,
-            class_name='logical-partition',
+            class_name=RC_LOGICAL_PARTITION,
             session=cpc.manager.session,
             parent=cpc,
             base_uri='/api/logical-partitions',
@@ -539,9 +539,10 @@ class Lpar(BaseResource):
             set.
 
           secure_boot (bool):
-            Bollean controlling whether the system checks the software
+            Boolean controlling whether the system checks the software
             signature of what is loaded against what the distributor signed it
-            with. Requires z15 or later.
+            with. Requires z15 or later. It is only passed to the HMC when
+            `True`.
 
         Returns:
 
@@ -601,7 +602,7 @@ class Lpar(BaseResource):
                   boot_record_logical_block_address=None, os_ipl_token=None,
                   wait_for_completion=True, operation_timeout=None,
                   status_timeout=None, allow_status_exceptions=False,
-                  force=False):
+                  force=False, secure_boot=False):
         # pylint: disable=invalid-name
         """
         Load a standalone dump program from a designated SCSI device
@@ -692,6 +693,12 @@ class Lpar(BaseResource):
             Boolean controlling whether this operation is permitted when the
             LPAR is in the "operating" status.
 
+          secure_boot (bool):
+            Boolean controlling whether the system checks the software
+            signature of what is loaded against what the distributor signed it
+            with. Requires z15 or later. It is only passed to the HMC when
+            `True`.
+
         Returns:
 
           `None` or :class:`~zhmcclient.Job`:
@@ -731,6 +738,8 @@ class Lpar(BaseResource):
             body['os-ipl-token'] = os_ipl_token
         if force:
             body['force'] = force
+        if secure_boot:
+            body['secure-boot'] = secure_boot
         result = self.manager.session.post(
             self.uri + '/operations/scsi-dump',
             body,
@@ -885,7 +894,7 @@ class Lpar(BaseResource):
         status has reached the desired value. If `wait_for_completion=True`,
         this method repeatedly checks the status of the LPAR after the HMC
         operation has completed, and waits until the status is in the desired
-        state "operating", or if `allow_status_exceptions` was
+        state "not-operating", or if `allow_status_exceptions` was
         set additionally in the state "exceptions".
 
         Authorization requirements:
@@ -903,7 +912,7 @@ class Lpar(BaseResource):
 
             * If `True`, this method will wait for completion of the
               asynchronous job performing the operation, and for the status
-              becoming "operating" (or in addition "exceptions", if
+              becoming "not-operating" (or in addition "exceptions", if
               `allow_status_exceptions` was set.
 
             * If `False`, this method will return immediately once the HMC has
@@ -951,14 +960,14 @@ class Lpar(BaseResource):
           :exc:`~zhmcclient.StatusTimeout`: The timeout expired while
             waiting for the desired LPAR status.
         """
-        body = {}
+        body = None
         result = self.manager.session.post(
             self.uri + '/operations/stop',
             body,
             wait_for_completion=wait_for_completion,
             operation_timeout=operation_timeout)
         if wait_for_completion:
-            statuses = ["operating"]
+            statuses = ["not-operating"]
             if allow_status_exceptions:
                 statuses.append("exceptions")
             self.wait_for_status(statuses, status_timeout)
