@@ -42,7 +42,7 @@ from ._nic import NicManager
 from ._hba import HbaManager
 from ._virtual_function import VirtualFunctionManager
 from ._logging import logged_api_call
-from ._utils import matches_filters, divide_filter_args
+from ._utils import matches_filters, divide_filter_args, RC_PARTITION
 
 __all__ = ['PartitionManager', 'Partition']
 
@@ -79,7 +79,7 @@ class PartitionManager(BaseManager):
 
         super(PartitionManager, self).__init__(
             resource_class=Partition,
-            class_name='partition',
+            class_name=RC_PARTITION,
             session=cpc.manager.session,
             parent=cpc,
             base_uri='/api/partitions',
@@ -1315,3 +1315,40 @@ class Partition(BaseResource):
                 if full_properties:
                     sg.pull_full_properties()
         return sg_list
+
+    def dump(self):
+        """
+        Dump this Partition resource with its properties and child resources
+        (recursively) as a resource definition.
+
+        The returned resource definition has the following format::
+
+            {
+                # Resource properties:
+                "properties": {...},
+
+                # Child resources:
+                "nics": [...],
+                "hbas": [...],
+                "virtual_functions": [...],
+            }
+
+        Returns:
+          dict: Resource definition of this resource.
+        """
+
+        # Dump the resource properties
+        resource_dict = super(Partition, self).dump()
+
+        # Dump the child resources
+        nics = self.nics.dump()
+        if nics:
+            resource_dict['nics'] = nics
+        hbas = self.hbas.dump()
+        if hbas:
+            resource_dict['hbas'] = hbas
+        virtual_functions = self.virtual_functions.dump()
+        if virtual_functions:
+            resource_dict['virtual_functions'] = virtual_functions
+
+        return resource_dict
