@@ -26,7 +26,7 @@ import copy
 from ._manager import BaseManager
 from ._resource import BaseResource
 from ._logging import logged_api_call
-from ._utils import matches_filters, divide_filter_args
+from ._utils import matches_filters, divide_filter_args, RC_PASSWORD_RULE
 
 __all__ = ['PasswordRuleManager', 'PasswordRule']
 
@@ -55,6 +55,8 @@ class PasswordRuleManager(BaseManager):
         # If the support for a resource property changes within the set of HMC
         # versions that support this type of resource, this list must be set up
         # for the version of the HMC this session is connected to.
+        # Because this resource has case-insensitive names, this list must
+        # contain the name property.
         query_props = [
             'name',
             'type',
@@ -62,14 +64,15 @@ class PasswordRuleManager(BaseManager):
 
         super(PasswordRuleManager, self).__init__(
             resource_class=PasswordRule,
-            class_name='password-rule',
+            class_name=RC_PASSWORD_RULE,
             session=console.manager.session,
             parent=console,
             base_uri='/api/console/password-rules',
             oid_prop='element-id',
             uri_prop='element-uri',
             name_prop='name',
-            query_props=query_props)
+            query_props=query_props,
+            case_insensitive_names=True)
 
     @property
     def console(self):
