@@ -22,12 +22,15 @@ import sys
 import json
 import time
 import re
-import collections
 from copy import copy
 try:
     from collections import OrderedDict
 except ImportError:
     from ordereddict import OrderedDict
+try:
+    from collections.abc import Iterable
+except ImportError:
+    from collections import Iterable
 import six
 import requests
 from requests.packages import urllib3
@@ -45,6 +48,7 @@ from ._constants import DEFAULT_CONNECT_TIMEOUT, DEFAULT_CONNECT_RETRIES, \
     DEFAULT_NAME_URI_CACHE_TIMETOLIVE, HMC_LOGGER_NAME, \
     HTML_REASON_WEB_SERVICES_DISABLED, HTML_REASON_OTHER, \
     DEFAULT_HMC_PORT
+from ._version import __version__
 
 __all__ = ['Session', 'Job', 'RetryTimeoutConfig', 'get_password_interface']
 
@@ -52,6 +56,7 @@ HMC_LOGGER = get_logger(HMC_LOGGER_NAME)
 
 _HMC_SCHEME = "https"
 _STD_HEADERS = {
+    'User-Agent': 'python-zhmcclient/{}'.format(__version__),
     'Content-type': 'application/json',
     'Accept': '*/*'
 }
@@ -65,17 +70,28 @@ def _handle_request_exc(exc, retry_timeout_config):
     raised.
     """
     if isinstance(exc, requests.exceptions.ConnectTimeout):
-        raise ConnectTimeout(_request_exc_message(exc), exc,
-                             retry_timeout_config.connect_timeout,
-                             retry_timeout_config.connect_retries)
+        new_exc = ConnectTimeout(_request_exc_message(exc), exc,
+                                 retry_timeout_config.connect_timeout,
+                                 retry_timeout_config.connect_retries)
+        new_exc.__cause__ = None
+        raise new_exc  # ConnectTimeout
+
     if isinstance(exc, requests.exceptions.ReadTimeout):
-        raise ReadTimeout(_request_exc_message(exc), exc,
-                          retry_timeout_config.read_timeout,
-                          retry_timeout_config.read_retries)
+        new_exc = ReadTimeout(_request_exc_message(exc), exc,
+                              retry_timeout_config.read_timeout,
+                              retry_timeout_config.read_retries)
+        new_exc.__cause__ = None
+        raise new_exc  # ReadTimeout
+
     if isinstance(exc, requests.exceptions.RetryError):
-        raise RetriesExceeded(_request_exc_message(exc), exc,
-                              retry_timeout_config.connect_retries)
-    raise ConnectionError(_request_exc_message(exc), exc)
+        new_exc = RetriesExceeded(_request_exc_message(exc), exc,
+                                  retry_timeout_config.connect_retries)
+        new_exc.__cause__ = None
+        raise new_exc  # RetriesExceeded
+
+    new_exc = ConnectionError(_request_exc_message(exc), exc)
+    new_exc.__cause__ = None
+    raise new_exc  # ConnectionError
 
 
 def _request_exc_message(exc):
@@ -95,24 +111,26 @@ def _request_exc_message(exc):
     Returns:
       string: A reasonable exception message from the specified exception.
     """
-    if exc.args:
-        if isinstance(exc.args[0], Exception):
-            org_exc = exc.args[0]
+    messages = []
+    for arg in exc.args:
+
+        if isinstance(arg, Exception):
+            org_exc = arg
             if isinstance(org_exc, urllib3.exceptions.MaxRetryError):
-                reason_exc = org_exc.reason
-                message = str(reason_exc)
+                message = str(org_exc.reason)
             else:
-                message = str(org_exc.args[0])
+                message = str(org_exc)
         else:
-            message = str(exc.args[0])
+            message = str(arg)
 
         # Eliminate useless object repr at begin of the message
         m = re.match(r'^(\(<[^>]+>, \'(.*)\'\)|<[^>]+>: (.*))$', message)
         if m:
             message = m.group(2) or m.group(3)
-    else:
-        message = ""
-    return message
+
+        messages.append(message)
+
+    return ", ".join(messages)
 
 
 class RetryTimeoutConfig(object):
@@ -735,7 +753,8 @@ class Session(object):
         self._job_topic = None
 
     @staticmethod
-    def _log_http_request(method, url, headers=None, content=None):
+    def _log_http_request(method, url, headers=None, content=None,
+                          content_len=None):
         """
         Log the HTTP request of an HMC REST API call, at the debug level.
 
@@ -749,13 +768,18 @@ class Session(object):
 
           content (:term:`string`): HTTP body (aka content) used for the
             request (byte string or unicode string)
+
+          content_len (int): Length of content in Bytes, or `None` for
+            determining the length from the content string
         """
 
         content_msg = None
         if content is not None:
             if isinstance(content, six.binary_type):
-                content = content.decode('utf-8')
-            content_len = len(content)  # may change after JSON conversion
+                content = content.decode('utf-8', errors='ignore')
+            assert isinstance(content, six.text_type)
+            if content_len is None:
+                content_len = len(content)  # may change after JSON conversion
             try:
                 content_dict = json2dict(content)
             except ValueError:
@@ -804,6 +828,7 @@ class Session(object):
         if content is not None:
             if isinstance(content, six.binary_type):
                 content = content.decode('utf-8')
+            assert isinstance(content, six.text_type)
             content_len = len(content)  # may change after JSON conversion
             try:
                 content_dict = json2dict(content)
@@ -957,8 +982,15 @@ class Session(object):
             :attr:`~zhmcclient.Session.base_url` property).
             Must not be `None`.
 
-          body (:term:`json object`):
-            JSON object to be used as the HTTP request body (payload).
+          body (:term:`json object` or :term:`string` or file-like object):
+            The HTTP request body (payload).
+            If a JSON object (=dict) is provided, it will be serialized into
+            a UTF-8 encoded binary string.
+            If a Unicode string is provided, it will be encoded into a UTF-8
+            encoded binary string.
+            If a binary string is provided, it will be used unchanged.
+            If a file-like object is provided, it must return binary strings,
+            i.e. the file must have been opened in binary mode.
             `None` means the same as an empty dictionary, namely that no HTTP
             body is included in the request.
 
@@ -1038,25 +1070,44 @@ class Session(object):
         url = self.base_url + uri
         headers = self.headers.copy()  # Standard headers
 
+        log_len = None
         if body is None:
             data = None
+            log_data = None
         elif isinstance(body, dict):
             data = json.dumps(body)
-            # Content-type is already set in standard headers.
+            # Produces unicode string on py3, and unicode or byte string on py2.
+            # Content-type is already set to 'application/json' in standard
+            # headers.
+            if isinstance(data, six.text_type):
+                log_data = data
+                data = data.encode('utf-8')
+            else:
+                log_data = data
         elif isinstance(body, six.text_type):
             data = body.encode('utf-8')
+            log_data = body
             headers['Content-type'] = 'application/octet-stream'
         elif isinstance(body, six.binary_type):
             data = body
+            log_data = body
             headers['Content-type'] = 'application/octet-stream'
-        elif isinstance(body, collections.Iterable):
-            # For example, open files: open(), io.open()
+        elif isinstance(body, Iterable):
+            # File-like objects, e.g. io.BufferedReader or io.TextIOWrapper
+            # returned from open() or io.open().
             data = body
+            try:
+                mode = body.mode
+            except AttributeError:
+                mode = 'unknown'
+            log_data = u"<file-like object with mode {}>".format(mode)
+            log_len = -1
             headers['Content-type'] = 'application/octet-stream'
         else:
             raise TypeError("Body has invalid type: {}".format(type(body)))
 
-        self._log_http_request('POST', url, headers=headers, content=data)
+        self._log_http_request('POST', url, headers=headers, content=log_data,
+                               content_len=log_len)
         req = self._session or requests
         req_timeout = (self.retry_timeout_config.connect_timeout,
                        self.retry_timeout_config.read_timeout)
