@@ -45,7 +45,7 @@ import copy
 from ._manager import BaseManager
 from ._resource import BaseResource
 from ._logging import logged_api_call
-from ._utils import matches_filters, divide_filter_args
+from ._utils import matches_filters, divide_filter_args, RC_STORAGE_VOLUME
 
 __all__ = ['StorageVolumeManager', 'StorageVolume']
 
@@ -85,7 +85,7 @@ class StorageVolumeManager(BaseManager):
 
         super(StorageVolumeManager, self).__init__(
             resource_class=StorageVolume,
-            class_name='storage_volume',
+            class_name=RC_STORAGE_VOLUME,
             session=storage_group.manager.session,
             parent=storage_group,
             base_uri='{}/storage-volumes'.format(storage_group.uri),
@@ -410,6 +410,14 @@ class StorageVolume(BaseResource):
         self.manager._name_uri_cache.delete(
             self.get_properties_local(self.manager._name_prop, None))
 
+        parent_sv_uris = self.manager.parent.get_properties_local(
+            'storage-volume-uris')
+        if parent_sv_uris:
+            try:
+                parent_sv_uris.remove(self._uri)
+            except ValueError:
+                pass
+
     @logged_api_call
     def update_properties(self, properties, email_to_addresses=None,
                           email_cc_addresses=None, email_insert=None):
