@@ -26,15 +26,102 @@ except ImportError:
     # pylint: disable=deprecated-class
     from collections import Mapping, MutableSequence, Iterable
 from datetime import datetime
+from dateutil import parser
 import six
 import pytz
 from requests.utils import quote
 
-__all__ = ['datetime_from_timestamp', 'timestamp_from_datetime']
+__all__ = ['datetime_from_timestamp', 'timestamp_from_datetime',
+           'datetime_from_isoformat', 'datetime_to_isoformat']
 
 
 _EPOCH_DT = datetime(1970, 1, 1, 0, 0, 0, 0, pytz.utc)
 
+# Resource class names.
+# These are the values of the 'class' property on the resource objects.
+#
+# For CPCs in DPM mode:
+RC_ADAPTER = 'adapter'
+RC_CAPACITY_GROUP = 'capacity-group'
+RC_HBA = 'hba'
+RC_NIC = 'nic'
+RC_PARTITION = 'partition'
+RC_NETWORK_PORT = 'network-port'
+RC_STORAGE_PORT = 'storage-port'
+RC_STORAGE_TEMPLATE = 'storage-template'
+RC_STORAGE_GROUP = 'storage-group'
+RC_STORAGE_TEMPLATE_VOLUME = 'storage-template-volume'
+RC_STORAGE_VOLUME = 'storage-volume'
+RC_VIRTUAL_FUNCTION = 'virtual-function'
+RC_VIRTUAL_STORAGE_RESOURCE = 'virtual-storage-resource'
+RC_VIRTUAL_SWITCH = 'virtual-switch'
+RC_STORAGE_SITE = 'storage-site'
+RC_STORAGE_FABRIC = 'storage-fabric'
+RC_STORAGE_SWITCH = 'storage-switch'
+RC_STORAGE_SUBSYSTEM = 'storage-subsystem'
+RC_STORAGE_PATH = 'storage-path'
+RC_STORAGE_CONTROL_UNIT = 'storage-control-unit'
+RC_VIRTUAL_TAPE_RESOURCE = 'virtual-tape-resource'
+RC_TAPE_LINK = 'tape-link'
+RC_TAPE_LIBRARY = 'tape-library'
+
+#
+# For CPCs in classic mode:
+RC_RESET_ACTIVATION_PROFILE = 'reset-activation-profile'
+RC_IMAGE_ACTIVATION_PROFILE = 'image-activation-profile'
+RC_LOAD_ACTIVATION_PROFILE = 'load-activation-profile'
+RC_LDAP_SERVER_DEFINITION = 'ldap-server-definition'
+RC_LOGICAL_PARTITION = 'logical-partition'
+#
+# For CPCs in any  mode and resources independent of CPCs:
+RC_CONSOLE = 'console'
+RC_CPC = 'cpc'
+RC_PASSWORD_RULE = 'password-rule'
+RC_TASK = 'task'
+RC_USER_PATTERN = 'user-pattern'
+RC_USER_ROLE = 'user-role'
+RC_USER = 'user'
+
+# Valid resource class names
+#:
+VALID_RESOURCE_CLASSES = frozenset([
+    RC_ADAPTER,
+    RC_CAPACITY_GROUP,
+    RC_HBA,
+    RC_NIC,
+    RC_PARTITION,
+    RC_NETWORK_PORT,
+    RC_STORAGE_PORT,
+    RC_STORAGE_TEMPLATE,
+    RC_STORAGE_GROUP,
+    RC_STORAGE_TEMPLATE_VOLUME,
+    RC_STORAGE_VOLUME,
+    RC_VIRTUAL_FUNCTION,
+    RC_VIRTUAL_STORAGE_RESOURCE,
+    RC_VIRTUAL_SWITCH,
+    RC_STORAGE_SITE,
+    RC_STORAGE_FABRIC,
+    RC_STORAGE_SWITCH,
+    RC_STORAGE_SUBSYSTEM,
+    RC_STORAGE_PATH,
+    RC_STORAGE_CONTROL_UNIT,
+    RC_VIRTUAL_TAPE_RESOURCE,
+    RC_TAPE_LINK,
+    RC_TAPE_LIBRARY,
+    RC_RESET_ACTIVATION_PROFILE,
+    RC_IMAGE_ACTIVATION_PROFILE,
+    RC_LOAD_ACTIVATION_PROFILE,
+    RC_LDAP_SERVER_DEFINITION,
+    RC_LOGICAL_PARTITION,
+    RC_CONSOLE,
+    RC_CPC,
+    RC_PASSWORD_RULE,
+    RC_TASK,
+    RC_USER_PATTERN,
+    RC_USER_ROLE,
+    RC_USER,
+])
+
 
 def _indent(text, amount, ch=' '):
     """Return the indent text, where each line is indented by `amount`
@@ -403,3 +490,46 @@ def matches_prop(obj, prop_name, prop_match):
             if prop_value == prop_match:
                 return True
     return False
+
+
+def datetime_from_isoformat(dt_str):
+    """
+    Return a datetime object representing the date time string in ISO8601
+    format.
+
+    This function is used to parse timestamp strings from the externalized
+    HMC definition.
+
+    The date time strings are parsed using dateutil.parse.isoparse(), which
+    supports the ISO8601 formats. The separator between the date portion and
+    the time portion can be ' ' or 'T', and the optional timezone portion can
+    be specified as 'shhmm' or 'shh:mm'.
+
+    If the date time string specifies a timezone, the returned datetime object
+    is timezone-aware. Otherwise, it is timezone-naive.
+    """
+    dt = parser.isoparse(dt_str)
+    return dt
+
+
+def datetime_to_isoformat(dt):
+    """
+    Return a date time string in ISO8601 format representing the datetime
+    object.
+
+    This function is used to create timestamp strings for the externalized
+    HMC definition.
+
+    The generated date time string has this format:
+
+        YYYY-MM-DD HH:MM:SS[.ssssss][shh:mm]
+
+    Where:
+      * .ssssss - is an optional part specifying microseconds. It is not created
+        when the datetime microsecond value is 0.
+      * shh:mm - is an optional part specifying the timezone offset with sign,
+        hours hh and minutes mm. It is not created when the datetime is
+        timezone-naive.
+    """
+    dt_str = dt.isoformat(sep=' ')
+    return dt_str
