@@ -19,20 +19,21 @@ Pytest fixtures for mocked HMCs.
 from __future__ import absolute_import
 
 import os
-import errno
 import logging
 import pytest
-import yaml
-import yamlloader
 import zhmcclient
 import zhmcclient_mock
 
 from .hmc_definitions import HMCDefinitionFile, HMCDefinition
 
-# Nicknames in HMC definition file
-TESTHMCDIR = os.getenv('TESTHMCDIR', 'tests')
-TESTHMCFILE = os.path.join(TESTHMCDIR, 'hmc_definitions.yaml')
-TESTHMC = os.getenv('TESTHMC', 'default')
+# Path name of HMC definition file
+DEFAULT_TESTHMCFILE = os.path.join('tests', 'hmc_definitions.yaml')
+TESTHMCFILE = os.getenv('TESTHMCFILE', DEFAULT_TESTHMCFILE)
+
+# Test nickname in HMC definition file
+DEFAULT_TESTHMC = 'default'
+TESTHMC = os.getenv('TESTHMC', DEFAULT_TESTHMC)
+
 HMC_DEF_LIST = HMCDefinitionFile(filepath=TESTHMCFILE).list_hmcs(TESTHMC)
 
 # Log file
@@ -97,8 +98,21 @@ def hmc_session(request, hmc_definition):
 
     Upon teardown, the `zhmcclient.Session` object is logged off.
     """
-    hd = hmc_definition
+    session = setup_hmc_session(hmc_definition)
+    yield session
+    teardown_hmc_session(session)
 
+
+def setup_hmc_session(hd):
+    """
+    Setup an HMC session and return a new zhmcclient.Session object for it.
+
+    If the HMC definition represents a real HMC, log on to an HMC and return
+    a new zhmcclient.Session object.
+
+    If the HMC definition represents a faked HMC, create a new faked environment
+    from that and return a zhmcclient_mock.FakedSession object.
+    """
     # We use the cached skip reason from previous attempts
     skip_msg = getattr(hd, 'skip_msg', None)
     if skip_msg:
@@ -107,38 +121,11 @@ def hmc_session(request, hmc_definition):
     if hd.faked_hmc_file:
         # A faked HMC
 
-        # Read the faked HMC file
+        # Create a faked session from the HMC definition file
         filepath = os.path.join(
             os.path.dirname(hd.hmc_filepath),
             hd.faked_hmc_file)
-        try:
-            with open(filepath) as fp:
-                try:
-                    data = yaml.load(fp, Loader=yamlloader.ordereddict.Loader)
-                except (yaml.parser.ParserError,
-                        yaml.scanner.ScannerError) as exc:
-                    new_exc = FakedHMCFileError(
-                        "Invalid YAML syntax in faked HMC file {0!r}: {1} {2}".
-                        format(filepath, exc.__class__.__name__, exc))
-                    new_exc.__cause__ = None
-                    raise new_exc  # FakedHMCFileError
-        except IOError as exc:
-            if exc.errno == errno.ENOENT:
-                new_exc = FakedHMCFileError(
-                    "The faked HMC file {0!r} was not found".
-                    format(filepath))
-                new_exc.__cause__ = None
-                raise new_exc  # FakedHMCFileError
-            raise
-
-        client = data['faked_client']
-        session = zhmcclient_mock.FakedSession(
-            client['hmc_host'],
-            client['hmc_name'],
-            client['hmc_version'],
-            client['api_version'])
-        for cpc in client['cpcs']:
-            session.hmc.cpcs.add(cpc['properties'])
+        session = zhmcclient_mock.FakedSession.from_hmc_yaml_file(filepath)
 
     else:
         # A real HMC
@@ -158,7 +145,8 @@ def hmc_session(request, hmc_definition):
 
         # Creating a session does not interact with the HMC (logon is deferred)
         session = zhmcclient.Session(
-            hd.hmc_host, hd.hmc_userid, hd.hmc_password)
+            hd.hmc_host, hd.hmc_userid, hd.hmc_password,
+            verify_cert=hd.hmc_verify_cert)
 
         # Check access to the HMC
         try:
@@ -172,6 +160,11 @@ def hmc_session(request, hmc_definition):
     hd.skip_msg = None
     session.hmc_definition = hd
 
-    yield session
+    return session
 
+
+def teardown_hmc_session(session):
+    """
+    Log off from an HMC session.
+    """
     session.logoff()
